==> qbittorrent_4.6.3.orig.tar.xz: qbittorrent-4.6.3/src/base/tagset.h <==
/*
 * Bittorrent Client using Qt and libtorrent.
 * Copyright (C) 2021  Mike Tzou (Chocobo1)
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 * In addition, as a special exception, the copyright holders give permission to
 * link this program with the OpenSSL project's "OpenSSL" library (or with
 * modified versions of it that use the same license as the "OpenSSL" library),
 * and distribute the linked executables. You must obey the GNU General Public
 * License in all respects for all of the code used other than "OpenSSL".  If you
 * modify file(s), you may extend this exception to your version of the file(s),
 * but you are not obligated to do so. If you do not wish to do so, delete this
 * exception statement from your version.
 */

#pragma once

#include <QMetaType>
#include <QString>

#include "base/orderedset.h"
#include "base/utils/compare.h"

class TagLessThan
{
public:
    bool operator()(const QString &left, const QString &right) const;

private:
    Utils::Compare::NaturalCompare<Qt::CaseInsensitive> m_compare;
    Utils::Compare::NaturalCompare<Qt::CaseSensitive> m_subCompare;
};

using TagSet = OrderedSet<QString, TagLessThan>;

Q_DECLARE_METATYPE(TagSet)

==> qbittorrent_5.1.2.orig.tar.xz: qbittorrent-5.1.2/src/base/tagset.h <==
/*
 * Bittorrent Client using Qt and libtorrent.
 * Copyright (C) 2023  Vladimir Golovnev <glassez@yandex.ru>
 * Copyright (C) 2021  Mike Tzou (Chocobo1)
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 * In addition, as a special exception, the copyright holders give permission to
 * link this program with the OpenSSL project's "OpenSSL" library (or with
 * modified versions of it that use the same license as the "OpenSSL" library),
 * and distribute the linked executables. You must obey the GNU General Public
 * License in all respects for all of the code used other than "OpenSSL".  If you
 * modify file(s), you may extend this exception to your version of the file(s),
 * but you are not obligated to do so. If you do not wish to do so, delete this
 * exception statement from your version.
 */

#pragma once

#include <QMetaType>

#include "orderedset.h"
#include "tag.h"
#include "utils/compare.h"

class TagLessThan
{
public:
    bool operator()(const Tag &left, const Tag &right) const;

private:
    Utils::Compare::NaturalCompare<Qt::CaseInsensitive> m_compare;
    Utils::Compare::NaturalCompare<Qt::CaseSensitive> m_subCompare;
};

using TagSet = OrderedSet<Tag, TagLessThan>;

Q_DECLARE_METATYPE(TagSet)
